package com.persagy.init;


import javax.servlet.ServletContextAttributeListener;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Service;

import com.googlecode.aviator.AviatorEvaluator;
import com.persagy.client.WebSocketClientFactory;
import com.persagy.constant.CommonConst;
import com.persagy.job.AlarmMessageThread;
import com.persagy.netty.client.NettyClient;
import com.persagy.netty.collect.IotCollectNettyClient;
import com.persagy.service.AlarmQuartzService;

import cn.hutool.core.thread.ThreadUtil;


@Service
@Order(1)
public class InitRunner implements ServletContextAttributeListener, CommandLineRunner {

    @Autowired
    AlarmQuartzService alarmQuartzService;
    
    @Autowired
    private WebSocketClientFactory webSocketClientFactory;
    
    @Autowired
    private IotCollectNettyClient iotCollectNettyClient;
    
    @Autowired
    private NettyClient nettyClient;

    @Override
    public void run(String... args) throws Exception {

        //5.0 开始引入了 LRU 缓存，可指定缓存的表达式个数，比如设置为最大 1 万个缓存结果：
        AviatorEvaluator.getInstance().useLRUExpressionCache(10000);
        if(!CommonConst.kafkaEnable) {
            //启动netty客户端，接受云端数据
            nettyClient.connect();
        }
        // 启动collect服务连接
        if (CommonConst.collectEnable) {
        	iotCollectNettyClient.connect();
		}
        
        //启动websocket,接受IOT采集庶数据
        webSocketClientFactory.retryOutCallWebSocketClient();
        //异步消费消息
        ThreadUtil.execAsync(new AlarmMessageThread(alarmQuartzService), true);
    }

}
